@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw fretboard chord diagrams
 
-our $VERSION = '0.0600';
+our $VERSION = '0.0700';
 
 use Moo;
 use strictures 2;
@@ -83,6 +83,12 @@ has fretboard => (
 );
 
 
+has showname => (
+    is      => 'rw',
+    default => sub { 1 },
+);
+
+
 has verbose => (
     is      => 'ro',
     default => sub { 0 },
@@ -235,16 +241,20 @@ sub draw {
         $string--;
     }
 
-    # Print the chord name
-    $i->string(
-        font  => $font,
-        text  => scalar(chordname(@chord)),
-        color => $BLACK,
-        x     => $SPACE,
-        y     => $SPACE + $self->frets * $SPACE - $self->frets - $SPACE / 4,
-        size  => $SPACE / 2,
-        aa    => 1,
-    );
+    # Print the chord name if requested
+    if ( $self->showname ) {
+        my $chord_name = $self->showname eq '1' ? chordname(@chord) : $self->showname;
+        print "Chord = $chord_name\n" if $self->verbose;
+        $i->string(
+            font  => $font,
+            text  => $chord_name,
+            color => $BLACK,
+            x     => $SPACE,
+            y     => $SPACE + $self->frets * $SPACE - $self->frets - $SPACE / 4,
+            size  => $SPACE / 2,
+            aa    => 1,
+        );
+    }
 
     $self->_output_image($i);
 }
@@ -364,18 +374,20 @@ sub _draw_horiz {
         $string++;
     }
 
-    # Print the chord name
-    my $chord_name = chordname(@chord);
-    print "Chord = $chord_name\n" if $self->verbose;
-    $i->string(
-        font  => $font,
-        text  => $chord_name,
-        color => $BLACK,
-        x     => $SPACE,
-        y     => $SPACE * 2 + $self->frets * $SPACE - $SPACE / 3,
-        size  => $SPACE / 2,
-        aa    => 1,
-    );
+    # Print the chord name if requested
+    if ( $self->showname ) {
+        my $chord_name = $self->showname eq '1' ? chordname(@chord) : $self->showname;
+        print "Chord = $chord_name\n" if $self->verbose;
+        $i->string(
+            font  => $font,
+            text  => $chord_name,
+            color => $BLACK,
+            x     => $SPACE,
+            y     => $SPACE * 2 + $self->frets * $SPACE - $SPACE / 3,
+            size  => $SPACE / 2,
+            aa    => 1,
+        );
+    }
 
     $self->_output_image($i);
 }
@@ -398,7 +410,7 @@ __END__
 
 =pod
 
-=encoding UTF-8
+=encoding utf-8
 
 =head1 NAME
 
@@ -406,7 +418,7 @@ Music::FretboardDiagram - Draw fretboard chord diagrams
 
 =head1 VERSION
 
-version 0.0600
+version 0.0700
 
 =head1 SYNOPSIS
 
@@ -421,6 +433,7 @@ version 0.0600
   $dia->chord('xx0232');
   $dia->position(5);
   $dia->outfile('mystery-chord');
+  $dia->showname('Xb'); # "X flat"
   $dia->draw;
 
   $dia = Music::FretboardDiagram->new(
@@ -563,6 +576,18 @@ the 6th string at the bottom.  The frets are numbered from left to right.
 
 A hashref of the string notes.  This is a computed attribute.
 
+=head2 showname
+
+  $dia->showname($chord_name);
+  $showname = $dia->showname;
+
+Show the chord name or not.
+
+Sometimes the computed chord name is not that accurate.  In those cases set the
+B<showname> to a string of your choosing before drawing.
+
+Default: 1
+
 =head2 verbose
 
   $verbose = $dia->verbose;
@@ -589,6 +614,10 @@ Construct the B<fretboard> attribute from the B<tuning>.
 
 Render the requested chord diagram as an image file of B<type>.
 
+=head1 THANK YOU
+
+Paweł Świderski for the horizontal drawing suggestion
+
 =head1 SEE ALSO
 
 The F<eg/> files in this distribution
